@@ -6,13 +6,14 @@ library(BatchGetSymbols)
 # set dates
 first.date <- Sys.Date() - 60
 last.date <- Sys.Date()
-
+freq.data <- 'daily'
 # set tickers
 tickers <- c('FB','NYSE:MMM','PETR4.SA','abcdef')
 
 l.out <- BatchGetSymbols(tickers = tickers, 
                          first.date = first.date,
                          last.date = last.date, 
+                         freq.data = freq.data,
                          cache.folder = file.path(tempdir(), 
                                                   'BGS_Cache') ) # cache in tempdir()
 
